@@ -122,8 +122,8 @@ for app in get_apps():
         for smok_dir in smok_dirs:
 
             test_name = u'{0}_{1}'.format(
-                app.__package__.replace('.', '_').upper(),
-                smok_dir).encode('utf-8')
+                app.__package__.replace('.', '_'),
+                os.path.basename(smok_dir).upper().encode('utf-8')
             
             attrs = {
                 'fixtures': [],
